NotificationLevel

Enum NotificationLevel 

pub enum NotificationLevel {
    Silent,
    Standard,
    Debug,
}
The amount of feedback information that is to be generated.

Variants



Silent

No feedback generated by base engine. Note that game modifiers called may choose to generate feedback messages themselves, which will not again be discarded once received by the base game engine.



Standard

Base level of feedback about in-game events.



Debug

Highest level of feedback, which includes emitting every internal game event processed